﻿using System;
using System.Drawing;

using MonoTouch.Foundation;
using MonoTouch.UIKit;
using Infragistics;

namespace SummaryRow
{
	public partial class SummaryRowViewController : UIViewController
	{
		IGGridView _gridView;
		CustomDSH _dsh;


		public SummaryRowViewController (IntPtr handle) : base (handle)
		{
		}

		#region View lifecycle

		public override void ViewDidLoad ()
		{
			base.ViewDidLoad ();
			
			_gridView = new IGGridView (this.View.Bounds, IGGridViewStyle.IGGridViewStyleDefault);
			_gridView.AutoresizingMask = UIViewAutoresizing.FlexibleDimensions;
			this.View.AddSubview (_gridView);

			_dsh = new CustomDSH ();
			_dsh.Data = IGSalesmanItem.GenerateData (100).ToArray ();
			_dsh.updateData ();
			_gridView.DataSource = _dsh;
		}

		#endregion
	}

	public class CustomDSH : IGGridViewDataSourceHelper
	{
		public override int NumberOfRowsInSection (IGGridView gridView, int section)
		{
			return this.Data.Length + 1;
		}

		float _total;

		public void updateData()
		{
			_total = 0; 

			foreach(IGSalesmanItem item in this.Data)
			{
				_total += item.YearToDateSales;
			}
		}

		public override IGGridViewCell CreateCell (IGGridView gridView, IGCellPath path)
		{
			IGCellPath normPath = this.NormalizePath (path);
			IGGridViewColumnDefinition colDef = (IGGridViewColumnDefinition)this.Columns[normPath.ColumnIndex];

			if(colDef != null)
			{
				IGGridViewCell cell = colDef.CreateCell (gridView, path, this);

				if (normPath.RowIndex == this.Data.Length) {
					if (colDef.FieldKey == "yearToDateSales")
						cell.TextLabel.Text = _total.ToString ();
				}

				return cell;
			}

			return null;
		}
	}
}

